@@ -1,13 +1,18 @@
-select.grpreg <- function(obj, criterion=c("BIC","AIC","GCV"), df.method=c("default","active"), smooth=FALSE, ...)
-{
+select.grpreg <- function(obj, criterion=c("BIC","AIC","GCV","AICc","EBIC"), df.method=c("default","active"), smooth=FALSE, ...) {
   criterion <- match.arg(criterion)
   df.method <- match.arg(df.method)
   ll <- logLik(obj, df.method=df.method, ...)
   df <- as.numeric(attr(ll,"df"))
+  d <- dim(obj$beta)
+  p <- if (length(d)==2) d[1]-1 else d[2]-1
+  j <- if(obj$family=="gaussian") df-2 else df-1
   
-  if (criterion=="AIC") IC <- AIC(ll)
-  if (criterion=="BIC") IC <- BIC(ll)
-  if (criterion=="GCV") IC <- (1/obj$n) * (-2) * as.numeric(ll) / (1-df/obj$n)^2
+  IC <- switch(criterion,
+               AIC = AIC(ll),
+               BIC = BIC(ll),
+               GCV = (1/obj$n) * (-2) * as.numeric(ll) / (1-df/obj$n)^2,
+               AICc = AIC(ll) + 2*df*(df+1)/(obj$n-df-1),
+               EBIC = BIC(ll) + 2*(lgamma(p+1) - lgamma(j+1) - lgamma(p-j+1)))
   n.l <- length(obj$lambda)
   if (smooth & (n.l < 4)) {
     smooth <- FALSE
